@@ -14,7 +14,7 @@
 #   limitations under the License.
 
 __author__ = 'Michael Gruber'
-__version__ = '0.1.19'
+__version__ = '0.1.20'
 
 __all__ = ['ANY_ARGUMENTS',
            'AT_LEAST_ONCE',
@@ -42,9 +42,9 @@ from types import ModuleType
 from fluentmock.exceptions import (CouldNotVerifyCallError,
                                    HasBeenCalledAtLeastOnceError,
                                    InvalidAttributeError,
-                                   InvalidUsageOfAnyArgumentsError,
+                                   InvalidUseOfAnyArgumentsError,
                                    NoCallsStoredError,
-                                   HasBeenCalledWithDifferentArgumentsError)
+                                   HasBeenCalledWithUnexpectedArgumentsError)
 from fluentmock.matchers import FluentMatcher, FluentAnyArguments, FluentAnyArgument
 
 LOGGER = getLogger(__name__)
@@ -81,27 +81,87 @@ class FluentTarget(object):
 
     def __init__(self, target, attribute_name=None):
         if isinstance(target, str):
-            self._target_name = target
-            self._target = import_module(self._target_name)
+            self.name = target
+            self.object = import_module(self.name)
         elif isinstance(target, ModuleType):
-            self._target_name = target.__name__
-            self._target = import_module(self._target_name)
+            self.name = target.__name__
+            self.object = import_module(self.name)
         else:
             target_type = type(target)
-            self._target_name = target_type.__module__ + '.' + target_type.__name__
-            self._target = target
+            self.name = target_type.__module__ + '.' + target_type.__name__
+            self.object = target
 
-        self._attribute_name = attribute_name
+        if attribute_name is not None and not hasattr(self.object, attribute_name):
+            raise InvalidAttributeError(self.name, attribute_name)
+
+        self.attribute_name = attribute_name
 
     @property
     def full_qualified_target_name(self):
-        return self._target_name + '.' + self._attribute_name
+        return self.name + '.' + self.attribute_name
 
     def is_equal_to(self, target, attribute_name):
-        return self._target == target and self._attribute_name == attribute_name
+        return self.object == target and self.attribute_name == attribute_name
+
+    def __repr__(self):
+        return self.full_qualified_target_name
 
 
-class FluentAnswer(object):
+class FluentCallEntry(object):
+
+    def __init__(self, target, attribute_name, arguments, keyword_arguments):
+        self.target = FluentTarget(target, attribute_name)
+        self.arguments = arguments
+        self.keyword_arguments = keyword_arguments
+
+    def matches(self, target, attribute_name, arguments, keyword_arguments):
+        if not self.target.is_equal_to(target, attribute_name):
+            return False
+
+        if self.arguments and self.arguments[0] is ANY_ARGUMENTS:
+            return True
+
+        if self.arguments == arguments and self.keyword_arguments == keyword_arguments:
+            return True
+
+        if len(self.arguments) != len(arguments):
+            return False
+
+        if len(self.keyword_arguments) != len(keyword_arguments):
+            return False
+
+        for index, argument in enumerate(arguments):
+            value = self.arguments[index]
+            if isinstance(value, FluentMatcher):
+                if not value.matches(argument):
+                    return False
+            elif isinstance(argument, FluentMatcher):
+                if not argument.matches(value):
+                    return False
+            elif value != argument:
+                return False
+
+        if len(self.keyword_arguments) > 0:
+            for key in self.keyword_arguments.keys():
+                if key not in keyword_arguments:
+                    return False
+
+            for key in self.keyword_arguments.keys():
+                if isinstance(self.keyword_arguments[key], FluentMatcher):
+                    if not self.keyword_arguments[key].matches(keyword_arguments[key]):
+                        return False
+                elif self.keyword_arguments[key] != keyword_arguments[key]:
+                    return False
+
+        return True
+
+    def __repr__(self):
+        call_object = call(*self.arguments, **self.keyword_arguments)
+        call_string = str(call_object)
+        return call_string[:4] + ' ' + str(self.target) + call_string[4:]
+
+
+class FluentAnswer(FluentCallEntry):
 
     class AnswerByReturning(object):
 
@@ -119,7 +179,8 @@ class FluentAnswer(object):
         def __call__(self):
             raise self._value
 
-    def __init__(self, arguments, keyword_arguments):
+    def __init__(self, target, attribute_name, arguments, keyword_arguments):
+        FluentCallEntry.__init__(self, target, attribute_name, arguments, keyword_arguments)
         self.arguments = arguments
         self.keyword_arguments = keyword_arguments
         self._answers = []
@@ -144,52 +205,19 @@ class FluentAnswer(object):
         self._answers.append(answer)
         return self
 
-    def matches(self, arguments, keyword_arguments):
-        if self.arguments and self.arguments[0] is ANY_ARGUMENTS:
-            return True
 
-        if self.arguments == arguments and self.keyword_arguments == keyword_arguments:
-            return True
-
-        if len(self.arguments) != len(arguments):
-            return False
-
-        if len(self.keyword_arguments) != len(keyword_arguments):
-            return False
-
-        for index, argument in enumerate(arguments):
-            if isinstance(self.arguments[index], FluentMatcher):
-                if not self.arguments[index].matches(argument):
-                    return False
-            elif self.arguments[index] != argument:
-                return False
-
-        if len(self.keyword_arguments) > 0:
-            for key in self.keyword_arguments.keys():
-                if key not in keyword_arguments:
-                    return False
-
-            for key in self.keyword_arguments.keys():
-                if isinstance(self.keyword_arguments[key], FluentMatcher):
-                    if not self.keyword_arguments[key].matches(keyword_arguments[key]):
-                        return False
-                elif self.keyword_arguments[key] != keyword_arguments[key]:
-                    return False
-
-        return True
-
-
-class FluentPatchEntry(FluentTarget):
+class FluentPatchEntry(object):
 
     def __init__(self, target, attribute_name):
-        FluentTarget.__init__(self, target, attribute_name)
+        self.target = FluentTarget(target, attribute_name)
+
         self._patch = None
 
     def patch_away_with(self, fluent_mock):
-        if isinstance(self._target, Mock):
-            setattr(self._target, self._attribute_name, fluent_mock)
+        if isinstance(self.target.object, Mock):
+            setattr(self.target.object, self.target.attribute_name, fluent_mock)
         else:
-            self._patch = patch(self.full_qualified_target_name)
+            self._patch = patch(self.target.full_qualified_target_name)
             mock = self._patch.__enter__()
             mock.side_effect = fluent_mock
 
@@ -198,27 +226,6 @@ class FluentPatchEntry(FluentTarget):
             self._patch.__exit__()
 
 
-class FluentCallEntry(FluentTarget):
-
-    def __init__(self, target, attribute_name, arguments, keyword_arguments):
-        FluentTarget.__init__(self, target, attribute_name)
-        self._arguments = arguments
-        self._keyword_arguments = keyword_arguments
-
-    def matches(self, target, attribute_name, arguments, keyword_arguments):
-        if self.is_equal_to(target, attribute_name):
-            if self._arguments == arguments and self._keyword_arguments == keyword_arguments:
-                return True
-
-        return False
-
-    def __repr__(self):
-        target_string = 'call {target_name}.{attribute_name}'.format(target_name=self._target_name,
-                                                                     attribute_name=self._attribute_name)
-        call_string = str(call(*self._arguments, **self._keyword_arguments))
-        return call_string.replace('call', target_string)
-
-
 class FluentMock(FluentTarget):
 
     def __init__(self, target, attribute_name):
@@ -226,11 +233,11 @@ class FluentMock(FluentTarget):
         self._answers = []
 
     def __call__(self, *arguments, **keyword_arguments):
-        call_entry = FluentCallEntry(self._target, self._attribute_name, arguments, keyword_arguments)
+        call_entry = FluentCallEntry(self.object, self.attribute_name, arguments, keyword_arguments)
         _call_entries.append(call_entry)
 
         for answer in self._answers:
-            if answer.matches(arguments, keyword_arguments):
+            if answer.matches(self.object, self.attribute_name, arguments, keyword_arguments):
                 return answer.next()
 
         return None
@@ -246,9 +253,9 @@ class FluentMockConfigurator(object):
 
     def __call__(self, *arguments, **keyword_arguments):
         if len(arguments) > 1 and ANY_ARGUMENTS in arguments:
-            raise InvalidUsageOfAnyArgumentsError()
+            raise InvalidUseOfAnyArgumentsError()
 
-        answer = FluentAnswer(arguments, keyword_arguments)
+        answer = FluentAnswer(self._fluent_mock.object, self._fluent_mock.attribute_name, arguments, keyword_arguments)
         self._fluent_mock.append_new_answer(answer)
         return answer
 
@@ -258,18 +265,13 @@ class FluentWhen(FluentTarget):
     def __init__(self, target):
         FluentTarget.__init__(self, target)
 
-    def _check_target_has_attribute(self, attribute_name):
-        if not hasattr(self._target, attribute_name):
-            raise InvalidAttributeError(self._target_name, attribute_name)
-
     def __getattr__(self, attribute_name):
-        self._check_target_has_attribute(attribute_name)
-        patch_entry = FluentPatchEntry(self._target, attribute_name)
+        patch_entry = FluentPatchEntry(self.object, attribute_name)
         _patch_entries.append(patch_entry)
 
-        configurator_key = (self._target, attribute_name)
+        configurator_key = (self.object, attribute_name)
         if not configurator_key in _configurators:
-            fluent_mock = FluentMock(self._target, attribute_name)
+            fluent_mock = FluentMock(self.object, attribute_name)
             mock_configurator = FluentMockConfigurator(fluent_mock)
             patch_entry.patch_away_with(fluent_mock)
             _configurators[configurator_key] = mock_configurator
@@ -288,16 +290,16 @@ class Verifier(FluentTarget):
             raise ValueError(error_message)
 
     def __getattr__(self, attribute_name):
-        self._attribute_name = attribute_name
+        self.attribute_name = attribute_name
 
-        if not hasattr(self._target, attribute_name):
-            raise InvalidAttributeError(self._target_name, attribute_name)
+        if not hasattr(self.object, attribute_name):
+            raise InvalidAttributeError(self.name, attribute_name)
 
         return self
 
     def __call__(self, *arguments, **keyword_arguments):
-        method_of_mock = getattr(self._target, self._attribute_name)
-        if isinstance(self._target, Mock) and isinstance(method_of_mock, Mock):
+        method_of_mock = getattr(self.object, self.attribute_name)
+        if isinstance(self.object, Mock) and isinstance(method_of_mock, Mock):
             if self._times == NEVER:
                 call_entry = call(*arguments, **keyword_arguments)
                 if call_entry in method_of_mock.call_args_list:
@@ -313,17 +315,17 @@ class Verifier(FluentTarget):
 
     def _assert_never_called(self, *arguments, **keyword_arguments):
         for call_entry in _call_entries:
-            if call_entry.matches(self._target, self._attribute_name, arguments, keyword_arguments):
+            if call_entry.matches(self.object, self.attribute_name, arguments, keyword_arguments):
                 raise HasBeenCalledAtLeastOnceError(call_entry)
 
     def _assert_called(self, *arguments, **keyword_arguments):
-        expected_call_entry = FluentCallEntry(self._target, self._attribute_name, arguments, keyword_arguments)
+        expected_call_entry = FluentCallEntry(self.object, self.attribute_name, arguments, keyword_arguments)
 
         if not _call_entries:
             raise NoCallsStoredError(expected_call_entry)
 
         for call_entry in _call_entries:
-            if call_entry.matches(self._target, self._attribute_name, arguments, keyword_arguments):
+            if call_entry.matches(self.object, self.attribute_name, arguments, keyword_arguments):
                 return
 
         found_calls = self._find_calls_to_same_target()
@@ -331,9 +333,9 @@ class Verifier(FluentTarget):
         if found_calls:
             if arguments and ANY_ARGUMENTS in arguments:
                 if len(arguments) > 1:
-                    raise InvalidUsageOfAnyArgumentsError()
+                    raise InvalidUseOfAnyArgumentsError()
                 return
-            raise HasBeenCalledWithDifferentArgumentsError(expected_call_entry, found_calls)
+            raise HasBeenCalledWithUnexpectedArgumentsError(expected_call_entry, found_calls)
 
         raise CouldNotVerifyCallError(expected_call_entry)
 
@@ -341,7 +343,8 @@ class Verifier(FluentTarget):
         found_calls = []
 
         for call_entry in _call_entries:
-            if call_entry.is_equal_to(self._target, self._attribute_name):
+            target = call_entry.target
+            if target.is_equal_to(self.object, self.attribute_name):
                 found_calls.append(call_entry)
 
         return found_calls
