@@ -32,12 +32,13 @@ class InvalidAttributeError(Exception):
         super(InvalidAttributeError, self).__init__(error_message)
 
 
-class InvalidUsageOfAnyArgumentsError(AssertionError):
+class InvalidUseOfAnyArgumentsError(AssertionError):
 
-    MESSAGE_FORMAT = 'Do not use ANY_ARGUMENTS together with other arguments!'
+    MESSAGE_FORMAT = """Do not use ANY_ARGUMENTS together with other arguments!
+Use ANY_ARGUMENT as a wildcard for single arguments."""
 
     def __init__(self):
-        super(InvalidUsageOfAnyArgumentsError, self).__init__(self.MESSAGE_FORMAT)
+        super(InvalidUseOfAnyArgumentsError, self).__init__(self.MESSAGE_FORMAT)
 
 
 class HasBeenCalledAtLeastOnceError(AssertionError):
@@ -50,7 +51,7 @@ but has been called at least once."""
         super(HasBeenCalledAtLeastOnceError, self).__init__(error_message)
 
 
-class HasBeenCalledWithDifferentArgumentsError(AssertionError):
+class HasBeenCalledWithUnexpectedArgumentsError(AssertionError):
 
     MESSAGE_FORMAT = """
 Expected: {expected}
@@ -65,7 +66,7 @@ Expected: {expected}
             for call_entry in found_calls[1:]:
                 error_message += self.ADDITIONAL_CALL_ENTRIES.format(actual=call_entry)
 
-        super(HasBeenCalledWithDifferentArgumentsError, self).__init__(error_message)
+        super(HasBeenCalledWithUnexpectedArgumentsError, self).__init__(error_message)
 
 
 class NoCallsStoredError(AssertionError):
